# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ..shared.resource_deleted import ResourceDeleted

__all__ = ["DocBulkDeleteResponse"]

DocBulkDeleteResponse: TypeAlias = List[ResourceDeleted]
