# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo

__all__ = [
    "TaskCreateParams",
    "Main",
    "MainEvaluateStep",
    "MainToolCallStep",
    "MainPromptStepInput",
    "MainPromptStepInputPromptUnionMember0",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainPromptStepInputPromptUnionMember0ToolCall",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainPromptStepInputToolChoice",
    "MainPromptStepInputToolChoiceNamedToolChoice",
    "MainPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainPromptStepInputToolsUnionMember1",
    "MainPromptStepInputToolsUnionMember1ToolRef",
    "MainPromptStepInputToolsUnionMember1ToolRefRef",
    "MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainGetStep",
    "MainSetStep",
    "MainLogStep",
    "MainYieldStep",
    "MainReturnStep",
    "MainSleepStep",
    "MainSleepStepSleep",
    "MainErrorWorkflowStep",
    "MainWaitForInputStep",
    "MainWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInput",
    "MainIfElseWorkflowStepInputThen",
    "MainIfElseWorkflowStepInputThenWaitForInputStep",
    "MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputThenEvaluateStep",
    "MainIfElseWorkflowStepInputThenToolCallStep",
    "MainIfElseWorkflowStepInputThenPromptStepInput",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputThenGetStep",
    "MainIfElseWorkflowStepInputThenSetStep",
    "MainIfElseWorkflowStepInputThenLogStep",
    "MainIfElseWorkflowStepInputThenYieldStep",
    "MainIfElseWorkflowStepInputThenReturnStep",
    "MainIfElseWorkflowStepInputThenSleepStep",
    "MainIfElseWorkflowStepInputThenSleepStepSleep",
    "MainIfElseWorkflowStepInputThenErrorWorkflowStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInput",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitch",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThen",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenEvaluateStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenToolCallStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInput",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenGetStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSetStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenLogStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenYieldStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenReturnStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSleepStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSleepStepSleep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenErrorWorkflowStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenWaitForInputStep",
    "MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputThenForeachStepInput",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeach",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDo",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoWaitForInputStep",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoEvaluateStep",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoToolCallStep",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInput",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoGetStep",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoSetStep",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoLogStep",
    "MainIfElseWorkflowStepInputThenForeachStepInputForeachDoYieldStep",
    "MainIfElseWorkflowStepInputThenParallelStepInput",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallel",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelEvaluateStep",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelToolCallStep",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInput",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelGetStep",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelSetStep",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelLogStep",
    "MainIfElseWorkflowStepInputThenParallelStepInputParallelYieldStep",
    "MainIfElseWorkflowStepInputThenThenInput",
    "MainIfElseWorkflowStepInputThenThenInputMap",
    "MainIfElseWorkflowStepInputThenThenInputMapEvaluateStep",
    "MainIfElseWorkflowStepInputThenThenInputMapToolCallStep",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInput",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputThenThenInputMapGetStep",
    "MainIfElseWorkflowStepInputThenThenInputMapSetStep",
    "MainIfElseWorkflowStepInputThenThenInputMapLogStep",
    "MainIfElseWorkflowStepInputThenThenInputMapYieldStep",
    "MainIfElseWorkflowStepInputElse",
    "MainIfElseWorkflowStepInputElseWaitForInputStep",
    "MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputElseEvaluateStep",
    "MainIfElseWorkflowStepInputElseToolCallStep",
    "MainIfElseWorkflowStepInputElsePromptStepInput",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputElseGetStep",
    "MainIfElseWorkflowStepInputElseSetStep",
    "MainIfElseWorkflowStepInputElseLogStep",
    "MainIfElseWorkflowStepInputElseYieldStep",
    "MainIfElseWorkflowStepInputElseReturnStep",
    "MainIfElseWorkflowStepInputElseSleepStep",
    "MainIfElseWorkflowStepInputElseSleepStepSleep",
    "MainIfElseWorkflowStepInputElseErrorWorkflowStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInput",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitch",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThen",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenEvaluateStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenToolCallStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInput",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenGetStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSetStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenLogStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenYieldStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenReturnStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSleepStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSleepStepSleep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenErrorWorkflowStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenWaitForInputStep",
    "MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputElseForeachStepInput",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeach",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDo",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoWaitForInputStep",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoEvaluateStep",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoToolCallStep",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInput",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoGetStep",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoSetStep",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoLogStep",
    "MainIfElseWorkflowStepInputElseForeachStepInputForeachDoYieldStep",
    "MainIfElseWorkflowStepInputElseParallelStepInput",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallel",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelEvaluateStep",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelToolCallStep",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInput",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelGetStep",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelSetStep",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelLogStep",
    "MainIfElseWorkflowStepInputElseParallelStepInputParallelYieldStep",
    "MainIfElseWorkflowStepInputElseElseInput",
    "MainIfElseWorkflowStepInputElseElseInputMap",
    "MainIfElseWorkflowStepInputElseElseInputMapEvaluateStep",
    "MainIfElseWorkflowStepInputElseElseInputMapToolCallStep",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInput",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputElseElseInputMapGetStep",
    "MainIfElseWorkflowStepInputElseElseInputMapSetStep",
    "MainIfElseWorkflowStepInputElseElseInputMapLogStep",
    "MainIfElseWorkflowStepInputElseElseInputMapYieldStep",
    "MainSwitchStepInput",
    "MainSwitchStepInputSwitch",
    "MainSwitchStepInputSwitchThen",
    "MainSwitchStepInputSwitchThenEvaluateStep",
    "MainSwitchStepInputSwitchThenToolCallStep",
    "MainSwitchStepInputSwitchThenPromptStepInput",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoice",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainSwitchStepInputSwitchThenGetStep",
    "MainSwitchStepInputSwitchThenSetStep",
    "MainSwitchStepInputSwitchThenLogStep",
    "MainSwitchStepInputSwitchThenYieldStep",
    "MainSwitchStepInputSwitchThenReturnStep",
    "MainSwitchStepInputSwitchThenSleepStep",
    "MainSwitchStepInputSwitchThenSleepStepSleep",
    "MainSwitchStepInputSwitchThenErrorWorkflowStep",
    "MainSwitchStepInputSwitchThenWaitForInputStep",
    "MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput",
    "MainForeachStepInput",
    "MainForeachStepInputForeach",
    "MainForeachStepInputForeachDo",
    "MainForeachStepInputForeachDoWaitForInputStep",
    "MainForeachStepInputForeachDoWaitForInputStepWaitForInput",
    "MainForeachStepInputForeachDoEvaluateStep",
    "MainForeachStepInputForeachDoToolCallStep",
    "MainForeachStepInputForeachDoPromptStepInput",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolChoice",
    "MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice",
    "MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainForeachStepInputForeachDoGetStep",
    "MainForeachStepInputForeachDoSetStep",
    "MainForeachStepInputForeachDoLogStep",
    "MainForeachStepInputForeachDoYieldStep",
    "MainParallelStepInput",
    "MainParallelStepInputParallel",
    "MainParallelStepInputParallelEvaluateStep",
    "MainParallelStepInputParallelToolCallStep",
    "MainParallelStepInputParallelPromptStepInput",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainParallelStepInputParallelPromptStepInputToolChoice",
    "MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice",
    "MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainParallelStepInputParallelGetStep",
    "MainParallelStepInputParallelSetStep",
    "MainParallelStepInputParallelLogStep",
    "MainParallelStepInputParallelYieldStep",
    "MainMainInput",
    "MainMainInputMap",
    "MainMainInputMapEvaluateStep",
    "MainMainInputMapToolCallStep",
    "MainMainInputMapPromptStepInput",
    "MainMainInputMapPromptStepInputPromptUnionMember0",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCall",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainMainInputMapPromptStepInputToolChoice",
    "MainMainInputMapPromptStepInputToolChoiceNamedToolChoice",
    "MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainMainInputMapPromptStepInputToolsUnionMember1",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRef",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainMainInputMapGetStep",
    "MainMainInputMapSetStep",
    "MainMainInputMapLogStep",
    "MainMainInputMapYieldStep",
    "Tool",
    "ToolAPICall",
    "ToolAPICallSecrets",
    "ToolBash20241022",
    "ToolComputer20241022",
    "ToolFunction",
    "ToolIntegration",
    "ToolIntegrationDummyIntegrationDef",
    "ToolIntegrationBraveIntegrationDef",
    "ToolIntegrationBraveIntegrationDefArguments",
    "ToolIntegrationBraveIntegrationDefSetup",
    "ToolIntegrationEmailIntegrationDef",
    "ToolIntegrationEmailIntegrationDefArguments",
    "ToolIntegrationEmailIntegrationDefSetup",
    "ToolIntegrationSpiderIntegrationDef",
    "ToolIntegrationSpiderIntegrationDefArguments",
    "ToolIntegrationSpiderIntegrationDefSetup",
    "ToolIntegrationWikipediaIntegrationDef",
    "ToolIntegrationWikipediaIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDef",
    "ToolIntegrationWeatherIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDefSetup",
    "ToolIntegrationMailgunIntegrationDef",
    "ToolIntegrationMailgunIntegrationDefArguments",
    "ToolIntegrationMailgunIntegrationDefSetup",
    "ToolIntegrationBrowserbaseContextIntegrationDef",
    "ToolIntegrationBrowserbaseContextIntegrationDefArguments",
    "ToolIntegrationBrowserbaseContextIntegrationDefSetup",
    "ToolIntegrationBrowserbaseExtensionIntegrationDef",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDef",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDef",
    "ToolIntegrationRemoteBrowserIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDefArguments",
    "ToolIntegrationLlamaParseIntegrationDef",
    "ToolIntegrationLlamaParseIntegrationDefArguments",
    "ToolIntegrationLlamaParseIntegrationDefSetup",
    "ToolIntegrationFfmpegIntegrationDef",
    "ToolIntegrationFfmpegIntegrationDefArguments",
    "ToolIntegrationCloudinaryUploadIntegrationDef",
    "ToolIntegrationCloudinaryUploadIntegrationDefArguments",
    "ToolIntegrationCloudinaryUploadIntegrationDefSetup",
    "ToolIntegrationCloudinaryEditIntegrationDef",
    "ToolIntegrationCloudinaryEditIntegrationDefArguments",
    "ToolIntegrationCloudinaryEditIntegrationDefSetup",
    "ToolIntegrationArxivIntegrationDef",
    "ToolIntegrationArxivIntegrationDefArguments",
    "ToolIntegrationUnstructuredIntegrationDef",
    "ToolIntegrationUnstructuredIntegrationDefArguments",
    "ToolIntegrationUnstructuredIntegrationDefSetup",
    "ToolIntegrationAlgoliaIntegrationDef",
    "ToolIntegrationAlgoliaIntegrationDefArguments",
    "ToolIntegrationAlgoliaIntegrationDefSetup",
    "ToolSystem",
    "ToolTextEditor20241022",
]


class TaskCreateParams(TypedDict, total=False):
    main: Required[Iterable[Main]]

    name: Required[str]

    canonical_name: Optional[str]

    description: str

    inherit_tools: bool

    input_schema: Optional[object]

    metadata: Optional[object]

    tools: Iterable[Tool]


class MainEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(TypedDict, total=False):
    image_url: Required[
        MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(TypedDict, total=False):
    content: Required[
        Union[
            Iterable[MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0],
            Iterable[MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: object

    bash_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022]

    computer_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022]

    integration: object

    system: object

    text_editor_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022]

    type: Literal["function"]


class MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainPromptStepInputPromptUnionMember0(_MainPromptStepInputPromptUnionMember0ReservedKeywords, total=False):
    content: Required[Union[List[str], Iterable[MainPromptStepInputPromptUnionMember0ContentUnionMember1], str, None]]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainPromptStepInputPromptUnionMember0ToolCall]]


class MainPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainPromptStepInputToolChoiceNamedToolChoiceFunction]


MainPromptStepInputToolChoice: TypeAlias = Union[Literal["auto", "none"], MainPromptStepInputToolChoiceNamedToolChoice]


class MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[str, MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets]
    ]

    timeout: Optional[int]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(TypedDict, total=False):
    description: object

    name: object

    parameters: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(TypedDict, total=False):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall]
    """API call definition"""

    bash_20241022: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022]

    computer_20241022: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction]
    """Function definition"""

    integration: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration]
    """Brave integration definition"""

    system: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem]
    """System definition"""

    text_editor_20241022: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1ToolRef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainReturnStepReservedKeywords = TypedDict(
    "_MainReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainReturnStep(_MainReturnStepReservedKeywords, total=False):
    label: Optional[str]


class MainSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainSleepStep(TypedDict, total=False):
    sleep: Required[MainSleepStepSleep]

    label: Optional[str]


class MainErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainWaitForInputStepWaitForInput]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputThenPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputThenPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputThenReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenReturnStep(
    _MainIfElseWorkflowStepInputThenReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputThenSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputThenSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords,
    total=False,
):
    content: Required[
        Union[
            List[str],
            Iterable[
                MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1
            ],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[
        Iterable[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall]
    ]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice(
    TypedDict, total=False
):
    function: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction
    ]


MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice,
]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef(
    TypedDict, total=False
):
    ref: Required[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInput(TypedDict, total=False):
    prompt: Required[
        Union[Iterable[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0], str]
    ]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolChoice]

    tools: Union[
        Literal["all"],
        Iterable[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1],
    ]

    unwrap: bool


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenReturnStep(
    _MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenWaitForInputStepWaitForInput]

    label: Optional[str]


MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThen: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenEvaluateStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenToolCallStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenPromptStepInput,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenGetStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSetStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenLogStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenYieldStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenReturnStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenSleepStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenErrorWorkflowStep,
    MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThenWaitForInputStep,
]


class MainIfElseWorkflowStepInputThenSwitchStepInputSwitch(TypedDict, total=False):
    case: Required[Literal["_"]]

    then: Required[MainIfElseWorkflowStepInputThenSwitchStepInputSwitchThen]


class MainIfElseWorkflowStepInputThenSwitchStepInput(TypedDict, total=False):
    switch: Required[Iterable[MainIfElseWorkflowStepInputThenSwitchStepInputSwitch]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputThenForeachStepInputForeachDoWaitForInputStepWaitForInput]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords,
    total=False,
):
    content: Required[
        Union[
            List[str],
            Iterable[
                MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1
            ],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[
        Iterable[MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall]
    ]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice(
    TypedDict, total=False
):
    function: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction
    ]


MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice,
]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef(
    TypedDict, total=False
):
    ref: Required[MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInput(TypedDict, total=False):
    prompt: Required[
        Union[Iterable[MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputPromptUnionMember0], str]
    ]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolChoice]

    tools: Union[
        Literal["all"],
        Iterable[MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInputToolsUnionMember1],
    ]

    unwrap: bool


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenForeachStepInputForeachDoYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainIfElseWorkflowStepInputThenForeachStepInputForeachDo: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoWaitForInputStep,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoEvaluateStep,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoToolCallStep,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoPromptStepInput,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoGetStep,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoSetStep,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoLogStep,
    MainIfElseWorkflowStepInputThenForeachStepInputForeachDoYieldStep,
]

_MainIfElseWorkflowStepInputThenForeachStepInputForeachReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenForeachStepInputForeachReservedKeywords",
    {
        "in": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenForeachStepInputForeach(
    _MainIfElseWorkflowStepInputThenForeachStepInputForeachReservedKeywords, total=False
):
    do: Required[MainIfElseWorkflowStepInputThenForeachStepInputForeachDo]


class MainIfElseWorkflowStepInputThenForeachStepInput(TypedDict, total=False):
    foreach: Required[MainIfElseWorkflowStepInputThenForeachStepInputForeach]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords,
    total=False,
):
    content: Required[
        Union[
            List[str],
            Iterable[
                MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1
            ],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[
        Iterable[MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall]
    ]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice(
    TypedDict, total=False
):
    function: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction
    ]


MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice,
]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef(
    TypedDict, total=False
):
    ref: Required[MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInput(TypedDict, total=False):
    prompt: Required[
        Union[Iterable[MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputPromptUnionMember0], str]
    ]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolChoice]

    tools: Union[
        Literal["all"],
        Iterable[MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInputToolsUnionMember1],
    ]

    unwrap: bool


class MainIfElseWorkflowStepInputThenParallelStepInputParallelGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenParallelStepInputParallelYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainIfElseWorkflowStepInputThenParallelStepInputParallel: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenParallelStepInputParallelEvaluateStep,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelToolCallStep,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelPromptStepInput,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelGetStep,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelSetStep,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelLogStep,
    MainIfElseWorkflowStepInputThenParallelStepInputParallelYieldStep,
]


class MainIfElseWorkflowStepInputThenParallelStepInput(TypedDict, total=False):
    parallel: Required[Iterable[MainIfElseWorkflowStepInputThenParallelStepInputParallel]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputThenThenInputMapPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputThenThenInputMapPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputThenThenInputMapGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenThenInputMapYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainIfElseWorkflowStepInputThenThenInputMap: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenThenInputMapEvaluateStep,
    MainIfElseWorkflowStepInputThenThenInputMapToolCallStep,
    MainIfElseWorkflowStepInputThenThenInputMapPromptStepInput,
    MainIfElseWorkflowStepInputThenThenInputMapGetStep,
    MainIfElseWorkflowStepInputThenThenInputMapSetStep,
    MainIfElseWorkflowStepInputThenThenInputMapLogStep,
    MainIfElseWorkflowStepInputThenThenInputMapYieldStep,
]


class MainIfElseWorkflowStepInputThenThenInput(TypedDict, total=False):
    map: Required[MainIfElseWorkflowStepInputThenThenInputMap]

    over: Required[str]

    initial: object

    label: Optional[str]

    parallelism: Optional[int]

    reduce: Optional[str]


MainIfElseWorkflowStepInputThen: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenWaitForInputStep,
    MainIfElseWorkflowStepInputThenEvaluateStep,
    MainIfElseWorkflowStepInputThenToolCallStep,
    MainIfElseWorkflowStepInputThenPromptStepInput,
    MainIfElseWorkflowStepInputThenGetStep,
    MainIfElseWorkflowStepInputThenSetStep,
    MainIfElseWorkflowStepInputThenLogStep,
    MainIfElseWorkflowStepInputThenYieldStep,
    MainIfElseWorkflowStepInputThenReturnStep,
    MainIfElseWorkflowStepInputThenSleepStep,
    MainIfElseWorkflowStepInputThenErrorWorkflowStep,
    MainIfElseWorkflowStepInputThenSwitchStepInput,
    MainIfElseWorkflowStepInputThenForeachStepInput,
    MainIfElseWorkflowStepInputThenParallelStepInput,
    MainIfElseWorkflowStepInputThenThenInput,
    object,
]


class MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputElseWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputElsePromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputElsePromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputElsePromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputElseGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputElseReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseReturnStep(
    _MainIfElseWorkflowStepInputElseReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputElseSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputElseSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputElseSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords,
    total=False,
):
    content: Required[
        Union[
            List[str],
            Iterable[
                MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1
            ],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[
        Iterable[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall]
    ]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice(
    TypedDict, total=False
):
    function: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction
    ]


MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice,
]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef(
    TypedDict, total=False
):
    ref: Required[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInput(TypedDict, total=False):
    prompt: Required[
        Union[Iterable[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0], str]
    ]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolChoice]

    tools: Union[
        Literal["all"],
        Iterable[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1],
    ]

    unwrap: bool


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenReturnStep(
    _MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenWaitForInputStepWaitForInput]

    label: Optional[str]


MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThen: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenEvaluateStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenToolCallStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenPromptStepInput,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenGetStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSetStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenLogStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenYieldStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenReturnStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenSleepStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenErrorWorkflowStep,
    MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThenWaitForInputStep,
]


class MainIfElseWorkflowStepInputElseSwitchStepInputSwitch(TypedDict, total=False):
    case: Required[Literal["_"]]

    then: Required[MainIfElseWorkflowStepInputElseSwitchStepInputSwitchThen]


class MainIfElseWorkflowStepInputElseSwitchStepInput(TypedDict, total=False):
    switch: Required[Iterable[MainIfElseWorkflowStepInputElseSwitchStepInputSwitch]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputElseForeachStepInputForeachDoWaitForInputStepWaitForInput]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords,
    total=False,
):
    content: Required[
        Union[
            List[str],
            Iterable[
                MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1
            ],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[
        Iterable[MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall]
    ]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice(
    TypedDict, total=False
):
    function: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction
    ]


MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice,
]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef(
    TypedDict, total=False
):
    ref: Required[MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInput(TypedDict, total=False):
    prompt: Required[
        Union[Iterable[MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputPromptUnionMember0], str]
    ]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolChoice]

    tools: Union[
        Literal["all"],
        Iterable[MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInputToolsUnionMember1],
    ]

    unwrap: bool


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseForeachStepInputForeachDoYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainIfElseWorkflowStepInputElseForeachStepInputForeachDo: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoWaitForInputStep,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoEvaluateStep,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoToolCallStep,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoPromptStepInput,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoGetStep,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoSetStep,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoLogStep,
    MainIfElseWorkflowStepInputElseForeachStepInputForeachDoYieldStep,
]

_MainIfElseWorkflowStepInputElseForeachStepInputForeachReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseForeachStepInputForeachReservedKeywords",
    {
        "in": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseForeachStepInputForeach(
    _MainIfElseWorkflowStepInputElseForeachStepInputForeachReservedKeywords, total=False
):
    do: Required[MainIfElseWorkflowStepInputElseForeachStepInputForeachDo]


class MainIfElseWorkflowStepInputElseForeachStepInput(TypedDict, total=False):
    foreach: Required[MainIfElseWorkflowStepInputElseForeachStepInputForeach]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords,
    total=False,
):
    content: Required[
        Union[
            List[str],
            Iterable[
                MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1
            ],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[
        Iterable[MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall]
    ]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice(
    TypedDict, total=False
):
    function: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction
    ]


MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice,
]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef(
    TypedDict, total=False
):
    ref: Required[MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInput(TypedDict, total=False):
    prompt: Required[
        Union[Iterable[MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputPromptUnionMember0], str]
    ]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolChoice]

    tools: Union[
        Literal["all"],
        Iterable[MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInputToolsUnionMember1],
    ]

    unwrap: bool


class MainIfElseWorkflowStepInputElseParallelStepInputParallelGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseParallelStepInputParallelYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainIfElseWorkflowStepInputElseParallelStepInputParallel: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseParallelStepInputParallelEvaluateStep,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelToolCallStep,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelPromptStepInput,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelGetStep,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelSetStep,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelLogStep,
    MainIfElseWorkflowStepInputElseParallelStepInputParallelYieldStep,
]


class MainIfElseWorkflowStepInputElseParallelStepInput(TypedDict, total=False):
    parallel: Required[Iterable[MainIfElseWorkflowStepInputElseParallelStepInputParallel]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: object

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoiceNamedToolChoiceFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(
    TypedDict, total=False
):
    id: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(
    TypedDict, total=False
):
    name: Optional[str]


MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputElseElseInputMapPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputElseElseInputMapPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputElseElseInputMapGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseElseInputMapYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainIfElseWorkflowStepInputElseElseInputMap: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseElseInputMapEvaluateStep,
    MainIfElseWorkflowStepInputElseElseInputMapToolCallStep,
    MainIfElseWorkflowStepInputElseElseInputMapPromptStepInput,
    MainIfElseWorkflowStepInputElseElseInputMapGetStep,
    MainIfElseWorkflowStepInputElseElseInputMapSetStep,
    MainIfElseWorkflowStepInputElseElseInputMapLogStep,
    MainIfElseWorkflowStepInputElseElseInputMapYieldStep,
]


class MainIfElseWorkflowStepInputElseElseInput(TypedDict, total=False):
    map: Required[MainIfElseWorkflowStepInputElseElseInputMap]

    over: Required[str]

    initial: object

    label: Optional[str]

    parallelism: Optional[int]

    reduce: Optional[str]


MainIfElseWorkflowStepInputElse: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseWaitForInputStep,
    MainIfElseWorkflowStepInputElseEvaluateStep,
    MainIfElseWorkflowStepInputElseToolCallStep,
    MainIfElseWorkflowStepInputElsePromptStepInput,
    MainIfElseWorkflowStepInputElseGetStep,
    MainIfElseWorkflowStepInputElseSetStep,
    MainIfElseWorkflowStepInputElseLogStep,
    MainIfElseWorkflowStepInputElseYieldStep,
    MainIfElseWorkflowStepInputElseReturnStep,
    MainIfElseWorkflowStepInputElseSleepStep,
    MainIfElseWorkflowStepInputElseErrorWorkflowStep,
    MainIfElseWorkflowStepInputElseSwitchStepInput,
    MainIfElseWorkflowStepInputElseForeachStepInput,
    MainIfElseWorkflowStepInputElseParallelStepInput,
    MainIfElseWorkflowStepInputElseElseInput,
    object,
]

_MainIfElseWorkflowStepInputReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputReservedKeywords",
    {
        "if": str,
        "else": Optional[MainIfElseWorkflowStepInputElse],
    },
    total=False,
)


class MainIfElseWorkflowStepInput(_MainIfElseWorkflowStepInputReservedKeywords, total=False):
    then: Required[MainIfElseWorkflowStepInputThen]
    """The steps to run if the condition is true"""

    label: Optional[str]


class MainSwitchStepInputSwitchThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainSwitchStepInputSwitchThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: object

    bash_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0(
    _MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall]]


class MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction]


MainSwitchStepInputSwitchThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainSwitchStepInputSwitchThenPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainSwitchStepInputSwitchThenPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainSwitchStepInputSwitchThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainSwitchStepInputSwitchThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainSwitchStepInputSwitchThenReturnStepReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainSwitchStepInputSwitchThenReturnStep(_MainSwitchStepInputSwitchThenReturnStepReservedKeywords, total=False):
    label: Optional[str]


class MainSwitchStepInputSwitchThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainSwitchStepInputSwitchThenSleepStep(TypedDict, total=False):
    sleep: Required[MainSwitchStepInputSwitchThenSleepStepSleep]

    label: Optional[str]


class MainSwitchStepInputSwitchThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainSwitchStepInputSwitchThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput]

    label: Optional[str]


MainSwitchStepInputSwitchThen: TypeAlias = Union[
    MainSwitchStepInputSwitchThenEvaluateStep,
    MainSwitchStepInputSwitchThenToolCallStep,
    MainSwitchStepInputSwitchThenPromptStepInput,
    MainSwitchStepInputSwitchThenGetStep,
    MainSwitchStepInputSwitchThenSetStep,
    MainSwitchStepInputSwitchThenLogStep,
    MainSwitchStepInputSwitchThenYieldStep,
    MainSwitchStepInputSwitchThenReturnStep,
    MainSwitchStepInputSwitchThenSleepStep,
    MainSwitchStepInputSwitchThenErrorWorkflowStep,
    MainSwitchStepInputSwitchThenWaitForInputStep,
]


class MainSwitchStepInputSwitch(TypedDict, total=False):
    case: Required[Literal["_"]]

    then: Required[MainSwitchStepInputSwitchThen]


class MainSwitchStepInput(TypedDict, total=False):
    switch: Required[Iterable[MainSwitchStepInputSwitch]]

    label: Optional[str]


class MainForeachStepInputForeachDoWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainForeachStepInputForeachDoWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainForeachStepInputForeachDoWaitForInputStepWaitForInput]

    label: Optional[str]


class MainForeachStepInputForeachDoEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainForeachStepInputForeachDoToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: object

    bash_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0(
    _MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall]]


class MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction]


MainForeachStepInputForeachDoPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainForeachStepInputForeachDoPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainForeachStepInputForeachDoPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainForeachStepInputForeachDoGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainForeachStepInputForeachDoSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainForeachStepInputForeachDoLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainForeachStepInputForeachDoYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainForeachStepInputForeachDo: TypeAlias = Union[
    MainForeachStepInputForeachDoWaitForInputStep,
    MainForeachStepInputForeachDoEvaluateStep,
    MainForeachStepInputForeachDoToolCallStep,
    MainForeachStepInputForeachDoPromptStepInput,
    MainForeachStepInputForeachDoGetStep,
    MainForeachStepInputForeachDoSetStep,
    MainForeachStepInputForeachDoLogStep,
    MainForeachStepInputForeachDoYieldStep,
]

_MainForeachStepInputForeachReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachReservedKeywords",
    {
        "in": str,
    },
    total=False,
)


class MainForeachStepInputForeach(_MainForeachStepInputForeachReservedKeywords, total=False):
    do: Required[MainForeachStepInputForeachDo]


class MainForeachStepInput(TypedDict, total=False):
    foreach: Required[MainForeachStepInputForeach]

    label: Optional[str]


class MainParallelStepInputParallelEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainParallelStepInputParallelToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: object

    bash_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0(
    _MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall]]


class MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction]


MainParallelStepInputParallelPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainParallelStepInputParallelPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainParallelStepInputParallelPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainParallelStepInputParallelPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainParallelStepInputParallelGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainParallelStepInputParallelSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainParallelStepInputParallelLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainParallelStepInputParallelYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainParallelStepInputParallel: TypeAlias = Union[
    MainParallelStepInputParallelEvaluateStep,
    MainParallelStepInputParallelToolCallStep,
    MainParallelStepInputParallelPromptStepInput,
    MainParallelStepInputParallelGetStep,
    MainParallelStepInputParallelSetStep,
    MainParallelStepInputParallelLogStep,
    MainParallelStepInputParallelYieldStep,
]


class MainParallelStepInput(TypedDict, total=False):
    parallel: Required[Iterable[MainParallelStepInputParallel]]

    label: Optional[str]


class MainMainInputMapEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainMainInputMapToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(TypedDict, total=False):
    content: Required[
        Union[
            Iterable[
                MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: object

    bash_20241022: Optional[MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022]

    computer_20241022: Optional[
        MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: object

    system: object

    text_editor_20241022: Optional[
        MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainMainInputMapPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainMainInputMapPromptStepInputPromptUnionMember0(
    _MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[List[str], Iterable[MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1], str, None]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainMainInputMapPromptStepInputPromptUnionMember0ToolCall]]


class MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainMainInputMapPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction]


MainMainInputMapPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainMainInputMapPromptStepInputToolChoiceNamedToolChoice
]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets(
    TypedDict, total=False
):
    name: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[
        Dict[
            str,
            MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallSecrets,
        ]
    ]

    timeout: Optional[int]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: object

    name: object

    parameters: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    brave_api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments(
    TypedDict, total=False
):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefSetup
    ]
    """Setup parameters for Spider integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments(
    _MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefArguments
    ]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDefSetup
    ]
    """Setup parameters for Mailgun integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Union[str, List[str], None]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup(
    TypedDict, total=False
):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefArguments
    ]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDefSetup
    ]
    """Setup parameters for Unstructured integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments(
    TypedDict, total=False
):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup(
    TypedDict, total=False
):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefArguments
    ]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDefSetup
    ]
    """Integration definition for Algolia"""


MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationMailgunIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationUnstructuredIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationAlgoliaIntegrationDef,
]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem]
    """System definition"""

    text_editor_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainMainInputMapPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainMainInputMapPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainMainInputMapPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[MainMainInputMapPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainMainInputMapPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainMainInputMapGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainMainInputMapSetStep(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]


class MainMainInputMapLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainMainInputMapYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainMainInputMap: TypeAlias = Union[
    MainMainInputMapEvaluateStep,
    MainMainInputMapToolCallStep,
    MainMainInputMapPromptStepInput,
    MainMainInputMapGetStep,
    MainMainInputMapSetStep,
    MainMainInputMapLogStep,
    MainMainInputMapYieldStep,
]


class MainMainInput(TypedDict, total=False):
    map: Required[MainMainInputMap]

    over: Required[str]

    initial: object

    label: Optional[str]

    parallelism: Optional[int]

    reduce: Optional[str]


Main: TypeAlias = Union[
    MainEvaluateStep,
    MainToolCallStep,
    MainPromptStepInput,
    MainGetStep,
    MainSetStep,
    MainLogStep,
    MainYieldStep,
    MainReturnStep,
    MainSleepStep,
    MainErrorWorkflowStep,
    MainWaitForInputStep,
    MainIfElseWorkflowStepInput,
    MainSwitchStepInput,
    MainForeachStepInput,
    MainParallelStepInput,
    MainMainInput,
]


class ToolAPICallSecrets(TypedDict, total=False):
    name: Required[str]


class ToolAPICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    secrets: Optional[Dict[str, ToolAPICallSecrets]]

    timeout: Optional[int]


class ToolBash20241022(TypedDict, total=False):
    name: str

    type: Literal["bash_20241022"]


class ToolComputer20241022(TypedDict, total=False):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class ToolFunction(TypedDict, total=False):
    description: object

    name: object

    parameters: Optional[object]


class ToolIntegrationDummyIntegrationDef(TypedDict, total=False):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object


class ToolIntegrationBraveIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]


class ToolIntegrationBraveIntegrationDefSetup(TypedDict, total=False):
    brave_api_key: Required[str]


class ToolIntegrationBraveIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBraveIntegrationDefArguments]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[ToolIntegrationBraveIntegrationDefSetup]
    """Integration definition for Brave Search"""


_ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class ToolIntegrationEmailIntegrationDefArguments(
    _ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords, total=False
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class ToolIntegrationEmailIntegrationDefSetup(TypedDict, total=False):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class ToolIntegrationEmailIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationEmailIntegrationDefArguments]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[ToolIntegrationEmailIntegrationDefSetup]
    """Setup parameters for Email integration"""


class ToolIntegrationSpiderIntegrationDefArguments(TypedDict, total=False):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]


class ToolIntegrationSpiderIntegrationDefSetup(TypedDict, total=False):
    spider_api_key: Required[str]


class ToolIntegrationSpiderIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationSpiderIntegrationDefArguments]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[ToolIntegrationSpiderIntegrationDefSetup]
    """Setup parameters for Spider integration"""


class ToolIntegrationWikipediaIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]

    load_max_docs: int


class ToolIntegrationWikipediaIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationWikipediaIntegrationDefArguments]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object


class ToolIntegrationWeatherIntegrationDefArguments(TypedDict, total=False):
    location: Required[str]


class ToolIntegrationWeatherIntegrationDefSetup(TypedDict, total=False):
    openweathermap_api_key: Required[str]


class ToolIntegrationWeatherIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationWeatherIntegrationDefArguments]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[ToolIntegrationWeatherIntegrationDefSetup]
    """Integration definition for Weather"""


_ToolIntegrationMailgunIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_ToolIntegrationMailgunIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class ToolIntegrationMailgunIntegrationDefArguments(
    _ToolIntegrationMailgunIntegrationDefArgumentsReservedKeywords, total=False
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]

    bcc: Optional[str]

    cc: Optional[str]


class ToolIntegrationMailgunIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]


class ToolIntegrationMailgunIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationMailgunIntegrationDefArguments]
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]]

    provider: Literal["mailgun"]

    setup: Optional[ToolIntegrationMailgunIntegrationDefSetup]
    """Setup parameters for Mailgun integration"""


class ToolIntegrationBrowserbaseContextIntegrationDefArguments(TypedDict, total=False):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class ToolIntegrationBrowserbaseContextIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseContextIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseContextIntegrationDefArguments]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseContextIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseExtensionIntegrationDefArguments(TypedDict, total=False):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class ToolIntegrationBrowserbaseExtensionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseExtensionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefArguments]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments(TypedDict, total=False):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseListSessionsIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments(TypedDict, total=False):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseCreateSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationRemoteBrowserIntegrationDefSetup(TypedDict, total=False):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class ToolIntegrationRemoteBrowserIntegrationDefArguments(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class ToolIntegrationRemoteBrowserIntegrationDef(TypedDict, total=False):
    setup: Required[ToolIntegrationRemoteBrowserIntegrationDefSetup]
    """The setup parameters for the remote browser"""

    arguments: Optional[ToolIntegrationRemoteBrowserIntegrationDefArguments]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class ToolIntegrationLlamaParseIntegrationDefArguments(TypedDict, total=False):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class ToolIntegrationLlamaParseIntegrationDefSetup(TypedDict, total=False):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class ToolIntegrationLlamaParseIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationLlamaParseIntegrationDefArguments]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[ToolIntegrationLlamaParseIntegrationDefSetup]
    """Setup parameters for LlamaParse integration"""


class ToolIntegrationFfmpegIntegrationDefArguments(TypedDict, total=False):
    cmd: Required[str]

    file: Union[str, List[str], None]


class ToolIntegrationFfmpegIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationFfmpegIntegrationDefArguments]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object


class ToolIntegrationCloudinaryUploadIntegrationDefArguments(TypedDict, total=False):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class ToolIntegrationCloudinaryUploadIntegrationDefSetup(TypedDict, total=False):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class ToolIntegrationCloudinaryUploadIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationCloudinaryUploadIntegrationDefArguments]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[ToolIntegrationCloudinaryUploadIntegrationDefSetup]
    """Setup parameters for Cloudinary integration"""


class ToolIntegrationCloudinaryEditIntegrationDefArguments(TypedDict, total=False):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class ToolIntegrationCloudinaryEditIntegrationDefSetup(TypedDict, total=False):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class ToolIntegrationCloudinaryEditIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationCloudinaryEditIntegrationDefArguments]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[ToolIntegrationCloudinaryEditIntegrationDefSetup]
    """Setup parameters for Cloudinary integration"""


class ToolIntegrationArxivIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class ToolIntegrationArxivIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationArxivIntegrationDefArguments]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: object


class ToolIntegrationUnstructuredIntegrationDefArguments(TypedDict, total=False):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]


class ToolIntegrationUnstructuredIntegrationDefSetup(TypedDict, total=False):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]


class ToolIntegrationUnstructuredIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationUnstructuredIntegrationDefArguments]
    """Arguments for Unstructured partition integration"""

    method: Optional[str]

    provider: Literal["unstructured"]

    setup: Optional[ToolIntegrationUnstructuredIntegrationDefSetup]
    """Setup parameters for Unstructured integration"""


class ToolIntegrationAlgoliaIntegrationDefArguments(TypedDict, total=False):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int


class ToolIntegrationAlgoliaIntegrationDefSetup(TypedDict, total=False):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]


class ToolIntegrationAlgoliaIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationAlgoliaIntegrationDefArguments]
    """Arguments for Algolia Search"""

    method: Optional[str]

    provider: Literal["algolia"]

    setup: Optional[ToolIntegrationAlgoliaIntegrationDefSetup]
    """Integration definition for Algolia"""


ToolIntegration: TypeAlias = Union[
    ToolIntegrationDummyIntegrationDef,
    ToolIntegrationBraveIntegrationDef,
    ToolIntegrationEmailIntegrationDef,
    ToolIntegrationSpiderIntegrationDef,
    ToolIntegrationWikipediaIntegrationDef,
    ToolIntegrationWeatherIntegrationDef,
    ToolIntegrationMailgunIntegrationDef,
    ToolIntegrationBrowserbaseContextIntegrationDef,
    ToolIntegrationBrowserbaseExtensionIntegrationDef,
    ToolIntegrationBrowserbaseListSessionsIntegrationDef,
    ToolIntegrationBrowserbaseCreateSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionIntegrationDef,
    ToolIntegrationBrowserbaseCompleteSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    ToolIntegrationRemoteBrowserIntegrationDef,
    ToolIntegrationLlamaParseIntegrationDef,
    ToolIntegrationFfmpegIntegrationDef,
    ToolIntegrationCloudinaryUploadIntegrationDef,
    ToolIntegrationCloudinaryEditIntegrationDef,
    ToolIntegrationArxivIntegrationDef,
    ToolIntegrationUnstructuredIntegrationDef,
    ToolIntegrationAlgoliaIntegrationDef,
]


class ToolSystem(TypedDict, total=False):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class ToolTextEditor20241022(TypedDict, total=False):
    name: str

    type: Literal["text_editor_20241022"]


class Tool(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[ToolAPICall]
    """API call definition"""

    bash_20241022: Optional[ToolBash20241022]

    computer_20241022: Optional[ToolComputer20241022]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[ToolFunction]
    """Function definition"""

    integration: Optional[ToolIntegration]
    """Brave integration definition"""

    system: Optional[ToolSystem]
    """System definition"""

    text_editor_20241022: Optional[ToolTextEditor20241022]
